@@ -25,6 +25,7 @@ Subpackages
    const
    date2date
    division
+   datetime
    esat
    fgui
    fsread
@@ -33,6 +34,7 @@ Subpackages
    mad
    mcplot
    morris_method
+   ncio
    position
    readnetcdf
    romanliterals
@@ -68,6 +70,9 @@ History
     * v1.20, added gridcellarea and kernel_regression, Apr 2022, Matthias Cuntz
     * v1.21, enhancements in color and kernel_regression,
       Apr 2022, Matthias Cuntz
+    * v1.22, added ncio, May 2022, Matthias Cuntz
+    * v1.23, added datetime module, Jun 2022, Matthias Cuntz
+    * v1.24, moved docu to Github Pages, Jun 2022, Matthias Cuntz
 
 """
 # version, author
@@ -85,6 +90,9 @@ from . import color
 from . import const
 # variety of specialised functions
 from . import functions
+# netCDF4 functions to copy netcdf file while doing some transformations on
+# variables and dimensions.
+from . import ncio
 
 # isotopic fractionation factors during liquid-water vapour equilibration
 from .alpha_equ_h2o import alpha_equ_h2o
@@ -104,6 +112,8 @@ from .date2date import fr2date, fr2en, fr2us
 from .date2date import us2date, us2en, us2fr
 # catch division by zero
 from .division import division, div
+# cftime extension
+from .datetime import date2dec, date2num, dec2date, num2date, datetime
 # saturation vapour pressure over water and ice
 from .esat import esat
 # GUI dialogs to choose files and directories using Tkinter
@@ -150,6 +160,7 @@ __all__ = ['__version__', '__author__',
            'fr2date', 'fr2en', 'fr2us',
            'us2date', 'us2en', 'us2fr',
            'division', 'div',
+           'date2dec', 'date2num', 'dec2date', 'num2date', 'datetime',
            'esat',
            'directory_from_gui', 'directories_from_gui',
            'file_from_gui', 'files_from_gui',
