@@ -2,7 +2,7 @@
 """
 Color palettes from ColorBrewer2
 
-It includes palettes from colorbrewer2.org:
+It includes palettes from colorbrewer2.org.
 
 Colorbrewer License
 -------------------
@@ -20,6 +20,7 @@ software distributed under the License is distributed on an
 either express or implied. See the License for the specific
 language governing permissions and limitations under the License.
 
+.. moduleauthor:: Matthias Cuntz
 
 History
     * Written Sep 2012, Matthias Cuntz
@@ -27,15 +28,13 @@ History
       Mar 2015, Matthias Cuntz
     * Ported to pyjams, Nov 2021, Matthias Cuntz
     * flake8 compatible, Nov 2021, Matthias Cuntz
-    * Prepend brewer_ to all palette names, Nov 2021, Matthias Cuntz
+    * Prepend brewer to all palette names, Nov 2021, Matthias Cuntz
 
 """
 
 __all__ = ['brewer_sequential', 'brewer_diverging', 'brewer_qualitative']
 
 
-# -------------------------------------------------------------------------------------------------
-
 # sequential color maps
 brewer_sequential = {
     'brewer_ylgn3': [(247, 252, 185), (173, 221, 142), (49, 163, 84)],
@@ -328,7 +327,6 @@ brewer_sequential = {
                       (82, 82, 82), (37, 37, 37), (0, 0, 0)],
 }
 
-# -------------------------------------------------------------------------------------------------
 
 # diverging color maps
 brewer_diverging = {
@@ -550,7 +548,6 @@ brewer_diverging = {
                         (26, 152, 80), (0, 104, 55)]
 }
 
-# -------------------------------------------------------------------------------------------------
 
 # qualitative color maps
 brewer_qualitative = {
