@@ -6,7 +6,7 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-:copyright: Copyright 2021- Matthias Cuntz, see AUTHORS.rst for details.
+:copyright: Copyright 2021-2022 Matthias Cuntz, see AUTHORS.rst for details.
 :license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
@@ -14,17 +14,26 @@ France.
 The following functions are provided:
 
 .. autosummary::
+   get_color
+   print_colors
    get_cmap
    print_palettes
    show_palettes
 
 History
     * Written Nov 2021, Matthias Cuntz
+    * Change order of color maps, Dec 2021, Matthias Cuntz
+    * More consistent docstrings, Jan 2022, Matthias Cuntz
+    * Added 'order' keyword, Feb 2022, Matthias Cuntz
+    * 'get_color', Mar 2022, Matthias Cuntz
+    * 'cname' can be list of names in 'get_color', Apr 2022, Matthias Cuntz
+    * Register ufz colors only once, Apr 2022, Matthias Cuntz
+    * Added print_colors, Apr 2022, Matthias Cuntz
 
 """
 
-
-__all__ = ['get_cmap', 'print_palettes', 'show_palettes']
+__all__ = ['get_color', 'print_colors',
+           'get_cmap', 'print_palettes', 'show_palettes']
 
 
 def _rgb2rgb(col):
@@ -38,7 +47,8 @@ def _rgb2rgb(col):
 
     Returns
     -------
-    RGB tuple with values from 0-1
+    tuple
+        RGB tuple with values from 0-1
 
     Examples
     --------
@@ -49,94 +59,261 @@ def _rgb2rgb(col):
     return tuple([ i / 255. for i in col ])
 
 
-def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
-             reverse=False, grey=False):
+def _to_grey(col):
     """
-    Get colors of defined palettes or continuous color maps
+    Transform RGB tuple to grey values
+
+    Parameters
+    ----------
+    col : iterable
+        RGB tuple
+
+    Returns
+    -------
+    tuple
+        RGB tuple with corresponding grey values
+
+    Examples
+    --------
+    col = (0, 0.5, 1)
+    col = _to_grey(col)
+
+    """
+    isgrey = 0.2125 * col[0] + 0.7154 * col[1] + 0.072 * col[2]
+    return (isgrey, isgrey, isgrey)
+
+
+def get_color(cname=''):
+    """
+    Register new named colors with Matplotlib and return named color(s)
+
+    Registers the named colors given in ufz_palettes.
+    Optionally returns the value(s) of the named color(s),
+    which can be any color name known to Matplotlib.
+
+    Parameters
+    ----------
+    cname : str or iterable of str, optional
+        Colour name(s)
+
+    Examples
+    --------
+    .. code-block:: python
+
+       col1 = get_color('ufz:blue')
+       col2 = get_color('xkcd:blue')
+       cols = get_color(['blue', 'red'])
+
+    """
+    from collections.abc import Iterable
+    import matplotlib.pyplot as plt
+    import pyjams.color
+
+    mapping = plt.cm.colors.get_named_colors_mapping
+    # register ufz colors if not yet done
+    if 'ufz:blue' not in mapping().keys():
+        ufz_colors = [ i for i in dir(pyjams.color)
+                       if i.startswith('ufz_')
+                       and not i.endswith('_palettes') ]
+        # ufz has only 1 list with colors
+        ufz_colors = eval('pyjams.color.' + ufz_colors[0])
+        mapping().update(ufz_colors)
+
+    if cname:
+        if isinstance(cname, Iterable) and (not isinstance(cname, str)):
+            out = [ mapping()[i] for i in cname ]
+            return out
+        else:
+            return mapping()[cname]
+
+
+def print_colors(collection=''):
+    """
+    Print the known named colors
+
+    Parameters
+    ----------
+    collection : str or list of strings, optional
+        Name(s) of color collection(s).
+        Known collections are 'base', 'tableau', 'ufz', 'css',
+        and 'xkcd'.
+
+    Returns
+    -------
+    None
+        Prints list of known named colors to console.
+
+    Examples
+    --------
+    .. code-block:: python
+
+       print_colors()
+
+    """
+    import matplotlib.pyplot as plt
+    import pyjams.color
+
+    if collection:
+        if isinstance(collection, str):
+            collections = [collection.lower()]
+        else:
+            collections = [ i.lower for i in collection ]
+    else:
+        collections = ['base', 'tableau', 'ufz', 'css', 'xkcd']
+
+    # register ufz colors if needed
+    get_color()
+    mapping = plt.cm.colors.get_named_colors_mapping
+    colors = mapping().keys()
+
+    if 'base' in collections:
+        print('base')
+        ll = [ cc for cc in colors if len(cc) == 1 ]
+        print('       ', list(ll))
+
+    if 'tableau' in collections:
+        print('tableau')
+        ll = [ cc for cc in colors if cc.startswith('tab:') ]
+        print('       ', list(ll))
+
+    if 'ufz' in collections:
+        print('ufz')
+        ll = [ cc for cc in colors if cc.startswith('ufz:') ]
+        print('       ', list(ll))
+
+    if 'css' in collections:
+        print('css')
+        ll = [ cc for cc in colors if (':' not in cc) and (len(cc) > 1) ]
+        print('       ', list(ll))
+
+    if 'xkcd' in collections:
+        print('xkcd')
+        ll = [ cc for cc in colors if cc.startswith('xkcd:') ]
+        print('       ', list(ll))
+
+
+def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
+             reverse=False, grey=False, order=None):
+    """
+    Get colors of defined palettes or continuous colormaps
 
     Parameters
     ----------
     palette : str
-        Name of color palette or continuous color map
+        Name of color palette or continuous colormap
     ncol : int, optional
-        Number of desired colors
-
+        Number of desired colors.
         If 0, all colors defined by the specific palette will be returned.
-        256 colors will be chosen for continuous color maps.
-
+        256 colors will be chosen for continuous colormaps.
         If > 0, existing color palettes will be subsampled to *ncol* colors.
-        *ncol* colors will be produced from continuous color maps.
+        *ncol* colors will be produced from continuous colormaps.
     offset : float (0-1), optional
-        Bottom fraction to exclude for subsample or continuous color maps
+        Bottom fraction to exclude for subsample or continuous colormaps
     upper : float (0-1), optional
-        Upper most fraction to include for subsample or continuous color maps
+        Upper most fraction to include for subsample or continuous colormaps
     reverse : bool, optional
-        If True, reverse color map. This can also be achieved by adding '_r' to
-        the palette name. Palettes that end with '_r' will not be reversed.
+        Reverse colormap if True (default: False). This can also be achieved by
+        adding '_r' to the palette name. Palettes that end with '_r' will not
+        be reversed.
     grey : bool, optional
-        If True, return grey equivalent colors.
+        Return grey equivalent colors if True (default: False).
+    order : str, optional
+        Order colors by 'hue', 'saturation', or 'value'.
+        This is done before *reverse* and *grey*
+        (default: order from color sources).
 
     Returns
     -------
-    list of RGB tuples or :class:`matplotlib.colors.Colormap`
+    list or matplotlib.colors.Colormap
+        List of RGB tuples or :class:`matplotlib.colors.Colormap`
+
+    Notes
+    -----
+    `get_cmap` always returns a list of RGB tuples or a Matplotlib
+    ListedColormap. You can use the *ncol*, *offset*, and *upper* keywords to
+    subsample colormaps. To get smoothly-varying colormaps, you can use the
+    method :meth:`matplotlib.colors.LinearSegmentedColormap.from_list`
+
+       cols = get_cmap('sron_ylorbr')
+
+       cmap = matplotlib.colors.LinearSegmentedColormap.from_list(cols)
+
+    You can get the color tuples from a LinearSegmentedColormap like this
+
+       colors = [ cmap(i) for i in range(cmap.N) ]
 
     Examples
     --------
-    cols = get_cmap('mathematica_dark_rainbow_256', 15)
+    .. code-block:: python
+
+       cols = get_cmap('mathematica_dark_rainbow_256', 15)
 
     """
     import matplotlib as mpl
+    import matplotlib.pyplot as plt
     import pyjams.color
+    from pyjams import argsort
 
     # _r at end of palette is same as reverse=True
     if palette.endswith('_r'):
         palette = palette[:-2]
         reverse = True
 
-    brewer_collections = [ i for i in dir(pyjams.color)
-                           if i.startswith('brewer_')
-                           and not i.endswith('_palettes') ]
-    mathematica_collections = [ i for i in dir(pyjams.color)
-                                if i.startswith('mathematica_')
-                                and not i.endswith('_palettes') ]
-    ncl_collections = [ i for i in dir(pyjams.color)
-                        if i.startswith('ncl_')
-                        and not i.endswith('_palettes') ]
-    oregon_collections = [ i for i in dir(pyjams.color)
-                           if i.startswith('oregon_')
+    pyjams_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('pyjams_')
                            and not i.endswith('_palettes') ]
+    sron_collections = [ i for i in dir(pyjams.color)
+                         if i.startswith('sron_')
+                         and not i.endswith('_palettes') ]
     sron2012_collections = [ i for i in dir(pyjams.color)
                              if i.startswith('sron2012_')
                              and not i.endswith('_palettes') ]
+    mathematica_collections = [ i for i in dir(pyjams.color)
+                                if i.startswith('mathematica_')
+                                and not i.endswith('_palettes') ]
+    oregon_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('oregon_')
+                           and not i.endswith('_palettes') ]
+    ncl_collections = [ i for i in dir(pyjams.color)
+                        if i.startswith('ncl_')
+                        and not i.endswith('_palettes') ]
+    brewer_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('brewer_')
+                           and not i.endswith('_palettes') ]
 
     found_palette = False
     nosubsample = False
-    for bb in brewer_collections:
-        dd = eval('pyjams.color.' + bb)
-        if palette in dd:
-            found_palette = True
-            colors = [ _rgb2rgb(i) for i in dd[palette] ]
+    miss = None
 
     if not found_palette:
-        for bb in mathematica_collections:
+        for bb in pyjams_collections:
             dd = eval('pyjams.color.' + bb)
             if palette in dd:
                 found_palette = True
                 colors = dd[palette]
 
     if not found_palette:
-        for bb in ncl_collections:
+        for bb in sron_collections:
             dd = eval('pyjams.color.' + bb)
             if palette in dd:
                 found_palette = True
-                colors = dd[palette]
-
-    if not found_palette:
-        for bb in oregon_collections:
-            dd = eval('pyjams.color.' + bb)
-            if palette in dd:
-                found_palette = True
-                colors = [ _rgb2rgb(i) for i in dd[palette] ]
+                if bb == 'sron_colors':
+                    colors = [ mpl.colors.colorConverter.to_rgb(i)
+                               for i in dd[palette] ]
+                elif bb == 'sron_colormaps':
+                    colors = [ mpl.colors.colorConverter.to_rgb(i)
+                               for i in dd[palette][0] ]
+                    miss = mpl.colors.colorConverter.to_rgb(dd[palette][1])
+                elif bb == 'sron_functions':
+                    nosubsample = True
+                    if ncol == 0:
+                        ncol1 = 23
+                    else:
+                        ncol1 = ncol
+                    cols = dd[palette](ncol1)
+                    colors = [ mpl.colors.colorConverter.to_rgb(i)
+                               for i in cols[0] ]
+                    miss = mpl.colors.colorConverter.to_rgb(cols[1])
 
     if not found_palette:
         for bb in sron2012_collections:
@@ -156,11 +333,35 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
                     for i in range(ncol1):
                         x = offset + float(i)/float(ncol1-1) * (upper-offset)
                         colors.append(tuple(dd[palette](x)))
-                else:
-                    raise ValueError('Unknown sron2012 palette. Coding Error.')
 
     if not found_palette:
-        amplmaps = mpl.pyplot.colormaps()
+        for bb in mathematica_collections:
+            dd = eval('pyjams.color.' + bb)
+            if palette in dd:
+                found_palette = True
+                colors = dd[palette]
+
+    if not found_palette:
+        for bb in oregon_collections:
+            dd = eval('pyjams.color.' + bb)
+            if palette in dd:
+                found_palette = True
+                colors = [ _rgb2rgb(i) for i in dd[palette] ]
+
+    if not found_palette:
+        for bb in ncl_collections:
+            dd = eval('pyjams.color.' + bb)
+            if palette in dd:
+                found_palette = True
+                colors = dd[palette]
+
+    if not found_palette:
+        # try:
+        #     amplmaps = plt.colormaps()
+        #     mplmaps = [ i for i in amplmaps if not i.endswith('_r') ]
+        # except AttributeError:
+        #     mplmaps = sorted(mpl.cm.datad.keys())
+        amplmaps = plt.colormaps()
         mplmaps = [ i for i in amplmaps if not i.endswith('_r') ]
         if palette in mplmaps:
             found_palette = True
@@ -184,16 +385,31 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
                     # mpl.colors.LinearSegmentedColormap
                     colors = [ cmap(i) for i in range(cmap.N) ]
 
+    if not found_palette:
+        for bb in brewer_collections:
+            dd = eval('pyjams.color.' + bb)
+            if palette in dd:
+                found_palette = True
+                colors = [ _rgb2rgb(i) for i in dd[palette] ]
+
     if not found_palette:
         raise ValueError(palette+' color palette not found.')
 
+    if order is not None:
+        hsv = ['hue', 'saturation', 'value']
+        if order.lower() in hsv:
+            oo = hsv.index(order.lower())
+        else:
+            raise ValueError('Sort order not known: ' + order)
+        ii = argsort([ mpl.colors.rgb_to_hsv(cc)[oo]
+                       for cc in colors ])
+        colors = [ colors[i] for i in ii ]
+
     if reverse:
         colors = colors[::-1]
 
     if grey:
-        for ii, cc in enumerate(colors):
-            isgrey = 0.2125 * cc[0] + 0.7154 * cc[1] + 0.072 * cc[2]
-            colors[ii] = (isgrey, isgrey, isgrey)
+        colors = [ _to_grey(i) for i in colors ]
 
     # subsample
     if (ncol > 0) and not nosubsample:
@@ -207,48 +423,62 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
 
     if as_cmap:
         colors = mpl.colors.ListedColormap(colors)
+        if mpl.__version__ > '3.4.0':
+            if miss is not None:
+                colors.set_bad(miss)
 
     return colors
 
 
 def print_palettes(collection=''):
     """
-    Print the known color palettes and continuous color maps
+    Print the known color palettes and continuous colormaps
 
     Parameters
     ----------
     collection : str or list of strings, optional
         Name(s) of color palette collection(s).
-        Known collections are 'brewer', 'mathematica', 'ncl',
-        'oregon', 'sron2012', and 'matplotlib'.
+        Known collections are 'pyjams', 'sron', 'sron2012', 'mathematica',
+        'oregon', 'ncl', 'matplotlib', and 'brewer'.
 
     Returns
     -------
-    Prints list of known color palettes and continuous color maps.
+    None
+        Prints list of known color palettes and continuous colormaps to
+        console.
 
     Examples
     --------
-    print_palettes()
+    .. code-block:: python
+
+       print_palettes()
 
     """
     import matplotlib as mpl
+    import matplotlib.pyplot as plt
     import pyjams.color
 
-    brewer_collections = [ i for i in dir(pyjams.color)
-                           if i.startswith('brewer_')
-                           and not i.endswith('_palettes') ]
-    mathematica_collections = [ i for i in dir(pyjams.color)
-                                if i.startswith('mathematica_')
-                                and not i.endswith('_palettes') ]
-    ncl_collections = [ i for i in dir(pyjams.color)
-                        if i.startswith('ncl_')
-                        and not i.endswith('_palettes') ]
-    oregon_collections = [ i for i in dir(pyjams.color)
-                           if i.startswith('oregon_')
+    pyjams_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('pyjams_')
                            and not i.endswith('_palettes') ]
+    sron_collections = [ i for i in dir(pyjams.color)
+                         if i.startswith('sron_')
+                         and not i.endswith('_palettes') ]
     sron2012_collections = [ i for i in dir(pyjams.color)
                              if i.startswith('sron2012_')
                              and not i.endswith('_palettes') ]
+    mathematica_collections = [ i for i in dir(pyjams.color)
+                                if i.startswith('mathematica_')
+                                and not i.endswith('_palettes') ]
+    oregon_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('oregon_')
+                           and not i.endswith('_palettes') ]
+    ncl_collections = [ i for i in dir(pyjams.color)
+                        if i.startswith('ncl_')
+                        and not i.endswith('_palettes') ]
+    brewer_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('brewer_')
+                           and not i.endswith('_palettes') ]
 
     if collection:
         if isinstance(collection, str):
@@ -256,33 +486,19 @@ def print_palettes(collection=''):
         else:
             collections = [ i.lower for i in collection ]
     else:
-        collections = ['brewer', 'mathematica', 'ncl', 'oregon',
-                       'sron2012', 'matplotlib']
+        collections = ['pyjams', 'sron', 'sron2012', 'mathematica',
+                       'oregon', 'ncl', 'matplotlib', 'brewer']
 
-    if 'brewer' in collections:
-        print('brewer')
-        for cc in brewer_collections:
+    if 'pyjams' in collections:
+        print('pyjams')
+        for cc in pyjams_collections:
             print('   ', cc)
             ll = eval('pyjams.color.' + cc + '.keys()')
             print('       ', list(ll))
 
-    if 'mathematica' in collections:
-        print('mathematica')
-        for cc in mathematica_collections:
-            print('   ', cc)
-            ll = eval('pyjams.color.' + cc + '.keys()')
-            print('       ', list(ll))
-
-    if 'ncl' in collections:
-        print('ncl')
-        for cc in ncl_collections:
-            print('   ', cc)
-            ll = eval('pyjams.color.' + cc + '.keys()')
-            print('       ', list(ll))
-
-    if 'oregon' in collections:
-        print('oregon')
-        for cc in oregon_collections:
+    if 'sron' in collections:
+        print('sron')
+        for cc in sron_collections:
             print('   ', cc)
             ll = eval('pyjams.color.' + cc + '.keys()')
             print('       ', list(ll))
@@ -294,32 +510,66 @@ def print_palettes(collection=''):
             ll = eval('pyjams.color.' + cc + '.keys()')
             print('       ', list(ll))
 
+    if 'mathematica' in collections:
+        print('mathematica')
+        for cc in mathematica_collections:
+            print('   ', cc)
+            ll = eval('pyjams.color.' + cc + '.keys()')
+            print('       ', list(ll))
+
+    if 'oregon' in collections:
+        print('oregon')
+        for cc in oregon_collections:
+            print('   ', cc)
+            ll = eval('pyjams.color.' + cc + '.keys()')
+            print('       ', list(ll))
+
+    if 'ncl' in collections:
+        print('ncl')
+        for cc in ncl_collections:
+            print('   ', cc)
+            ll = eval('pyjams.color.' + cc + '.keys()')
+            print('       ', list(ll))
+
     if 'matplotlib' in collections:
         print('matplotlib')
-        acmaps = mpl.pyplot.colormaps()
+        # try:
+        #     acmaps = plt.colormaps()
+        #     cmaps  = [ i for i in acmaps if not i.endswith('_r') ]
+        #     cmaps.sort()
+        # except AttributeError:
+        #     cmaps = sorted(mpl.colorbar.cm.datad.keys())
+        acmaps = plt.colormaps()
         cmaps  = [ i for i in acmaps if not i.endswith('_r') ]
         cmaps.sort()
         print('   ', cmaps)
 
+    if 'brewer' in collections:
+        print('brewer')
+        for cc in brewer_collections:
+            print('   ', cc)
+            ll = eval('pyjams.color.' + cc + '.keys()')
+            print('       ', list(ll))
 
-def _newfig(ifig, ititle):
+
+def _newfig(ifig, ititle):  # pragma: no cover
     """ Helper function for show_palettes """
     import matplotlib.pyplot as plt
     fig = plt.figure(ifig)
     fig.suptitle(ititle)
     plt.subplots_adjust(left=0.3, bottom=0.1,
                         right=0.95, top=0.95,
-                        wspace=0.05, hspace=0.2)
+                        wspace=0.05, hspace=0.5)
     return fig
 
 
-def _newsubplot(nrow, ncol, iplot, iname):
+def _newsubplot(nrow, ncol, iplot, iname, ncolors=0):  # pragma: no cover
     """ Helper function for show_palettes """
     import numpy as np
     import matplotlib.pyplot as plt
     ax = plt.subplot(nrow, ncol, iplot)
     ax.axis('off')
-    cmap = get_cmap(iname, as_cmap=True)
+    cmap = get_cmap(iname, ncolors, as_cmap=True)
     # ax.pcolormesh(np.outer(np.ones(cmap.N), np.arange(cmap.N)),
     #               cmap=cmap)
     ax.imshow(np.outer(np.ones(cmap.N), np.arange(cmap.N)),
@@ -328,12 +578,16 @@ def _newsubplot(nrow, ncol, iplot, iname):
     ymin, ymax = ax.get_ylim()
     dx = -0.01
     dy = 0.5
-    ax.text(xmin+dx*(xmax-xmin), ymin+dy*(ymax-ymin), iname,
+    if ncolors:
+        iiname = iname + '(' + str(ncolors) + ')'
+    else:
+        iiname = iname
+    ax.text(xmin+dx*(xmax-xmin), ymin+dy*(ymax-ymin), iiname,
             ha='right', va='center')
     # return ax
 
 
-def _savefig(fig, ifig, outtype, outfile, pdf_pages):
+def _savefig(fig, ifig, outtype, outfile, pdf_pages):  # pragma: no cover
     """ Helper function for show_palettes """
     import matplotlib.pyplot as plt
     if (outtype == 'pdf'):
@@ -348,9 +602,9 @@ def _savefig(fig, ifig, outtype, outfile, pdf_pages):
         pass
 
 
-def show_palettes(outfile='', collection=''):
+def show_palettes(outfile='', collection=''):  # pragma: no cover
     """
-    Show the known color palettes and continuous color maps
+    Show the known color palettes and continuous colormaps
 
     Parameters
     ----------
@@ -358,22 +612,27 @@ def show_palettes(outfile='', collection=''):
         Output file name. Output type will be determined from file suffix.
     collection : str or list of strings, optional
         Name(s) of color palette collection(s).
-        Known collections are 'brewer', 'mathematica', 'ncl',
-        'oregon', 'sron2012', and 'matplotlib'.
-
         All palettes will be shown if collection is empty or 'all'.
+        Known collections are: 'pyjams', 'sron', 'sron2012', 'mathematica',
+        'oregon', 'ncl', 'matplotlib', and 'brewer'.
 
     Returns
     -------
-    Plots known color palettes and continuous color maps.
+    None
+        Plots known color palettes and continuous colormaps in file or on
+        plotting window.
 
     Examples
     --------
-    show_palettes(outfile='pyjams_cmaps.pdf', collection=['mathematica', 'matplotlib'])
+    .. code-block:: python
+
+       show_palettes(outfile='pyjams_cmaps.pdf',
+                     collection=['mathematica', 'matplotlib'])
 
     """
-    import pyjams.color
     import matplotlib as mpl
+    import matplotlib.pyplot as plt
+    import pyjams.color
     # outtype
     if '.' in outfile:
         outtype = outfile[outfile.rfind('.')+1:]
@@ -390,8 +649,8 @@ def show_palettes(outfile='', collection=''):
     import matplotlib.pyplot as plt
 
     # which collections to include
-    collections = ['brewer', 'mathematica', 'ncl', 'oregon',
-                   'sron2012', 'matplotlib']
+    collections = ['pyjams', 'sron', 'sron2012', 'mathematica', 'oregon',
+                   'ncl', 'matplotlib', 'brewer']
     if collection:
         if isinstance(collection, str):
             if collection.lower() != 'all':
@@ -411,43 +670,61 @@ def show_palettes(outfile='', collection=''):
     nrow = 35
 
     # get collections
-    brewer_collections = [ i for i in dir(pyjams.color)
-                           if i.startswith('brewer_')
-                           and not i.endswith('_palettes') ]
-    mathematica_collections = [ i for i in dir(pyjams.color)
-                                if i.startswith('mathematica_')
-                                and not i.endswith('_palettes') ]
-    ncl_collections = [ i for i in dir(pyjams.color)
-                        if i.startswith('ncl_')
-                        and not i.endswith('_palettes') ]
-    oregon_collections = [ i for i in dir(pyjams.color)
-                           if i.startswith('oregon_')
+    pyjams_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('pyjams_')
                            and not i.endswith('_palettes') ]
+    sron_collections = [ i for i in dir(pyjams.color)
+                         if i.startswith('sron_')
+                         and not i.endswith('_palettes') ]
     sron2012_collections = [ i for i in dir(pyjams.color)
                              if i.startswith('sron2012_')
                              and not i.endswith('_palettes') ]
+    mathematica_collections = [ i for i in dir(pyjams.color)
+                                if i.startswith('mathematica_')
+                                and not i.endswith('_palettes') ]
+    oregon_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('oregon_')
+                           and not i.endswith('_palettes') ]
+    ncl_collections = [ i for i in dir(pyjams.color)
+                        if i.startswith('ncl_')
+                        and not i.endswith('_palettes') ]
+    brewer_collections = [ i for i in dir(pyjams.color)
+                           if i.startswith('brewer_')
+                           and not i.endswith('_palettes') ]
 
     all_collections = []
-    if 'brewer' in collections:
-        for cc in brewer_collections:
+    if 'pyjams' in collections:
+        for cc in pyjams_collections:
             all_collections.append(cc)
-    if 'mathematica' in collections:
-        for cc in mathematica_collections:
-            all_collections.append(cc)
-    if 'ncl' in collections:
-        for cc in ncl_collections:
-            all_collections.append(cc)
-    if 'oregon' in collections:
-        for cc in oregon_collections:
+    if 'sron' in collections:
+        for cc in sron_collections:
             all_collections.append(cc)
     if 'sron2012' in collections:
         for cc in sron2012_collections:
             all_collections.append(cc)
+    if 'mathematica' in collections:
+        for cc in mathematica_collections:
+            all_collections.append(cc)
+    if 'oregon' in collections:
+        for cc in oregon_collections:
+            all_collections.append(cc)
+    if 'ncl' in collections:
+        for cc in ncl_collections:
+            all_collections.append(cc)
     if 'matplotlib' in collections:
-        acmaps = mpl.pyplot.colormaps()
+        # try:
+        #     acmaps = plt.colormaps()
+        #     cmaps  = [ i for i in acmaps if not i.endswith('_r') ]
+        #     cmaps.sort()
+        # except AttributeError:
+        #     cmaps = sorted(mpl.colorbar.cm.datad.keys())
+        acmaps = plt.colormaps()
         cmaps  = [ i for i in acmaps if not i.endswith('_r') ]
         cmaps.sort()
         all_collections.extend(cmaps)
+    if 'brewer' in collections:
+        for cc in brewer_collections:
+            all_collections.append(cc)
 
     # plotting
     ifig = 0
@@ -475,6 +752,10 @@ def show_palettes(outfile='', collection=''):
             ipanel += 1
             # ax = _newsubplot(nrow, 1, ipanel, iname)
             _newsubplot(nrow, 1, ipanel, iname)
+            if collname == 'sron_functions':
+                for ncolors in range(1, 24):
+                    ipanel += 1
+                    _newsubplot(nrow, 1, ipanel, iname, ncolors)
             if ipanel == nrow:
                 _savefig(fig, ifig, outtype, outfile, pdf_pages)
                 ipanel = 0
