@@ -52,11 +52,13 @@ History
       Dec 2021, Matthias Cuntz
     * Wrapper functions between all standard formats, Dec 2021, Matthias Cuntz
     * More consistent docstrings, Jan 2022, Matthias Cuntz
+    * Use input2array, array2input, Jun 2022, Matthias Cuntz
 
 """
 import time as ptime
 import datetime as dt
 import numpy as np
+from .helper import input2array, array2input
 
 
 __all__ = ['date2date',
@@ -101,14 +103,17 @@ def _ensure_year(yr, isyr2):
 
 
 def date2date(edate, fr=False, format='', timesep=' ', full=False):
-    """Convert date representations between different regional variants.
+    """
+    Convert date representations between different regional variants
 
     Convert date notations between standard *DD.MM.YYYY hh:mm:ss*, English
     *YYYY-MM-DD hh:mm:ss*, American *MM/DD/YYYY hh:mm:ss*, and French
-    *DD/MM/YYYY hh:mm:ss* format. The routine determines the input date format
-    by the date separator '.', '-', or '/'. If the latter is detected, the
-    American format is assumed. One can set *fr=True* so that '/' detects the
-    French date format instead. The separator between date and time can be
+    *DD/MM/YYYY hh:mm:ss* format ('%d.%m.%Y %H:%M:%S', '%Y-%m-%d %H:%M:%S',
+    '%m/%d/%Y %H:%M:%S', and '%d/%m/%Y %H:%M:%S' in datetime.strftime/strptime
+    format notation, respectively). The routine determines the input date
+    format by the date separator '.', '-', or '/'. If the latter is detected,
+    the American format is assumed. One can set *fr=True* so that '/' detects
+    the French date format instead. The separator between date and time can be
     space ' ' or 'T', such as *YYYY-MM-DDThh:mm:ss*.
 
     Output format is given either by the calling name of the function (e.g.
@@ -212,19 +217,12 @@ def date2date(edate, fr=False, format='', timesep=' ', full=False):
 
     """
     # Input type and shape
-    if isinstance(edate, list):
-        idate = edate
-    elif isinstance(edate, tuple):
-        idate = list(edate)
-    elif isinstance(edate, np.ndarray):
-        idate = list(edate.flatten())
-    else:
-        idate = [edate]
-    ndate = len(idate)
+    idate = input2array(edate, undef='',
+                        default='01.01.0001 00:00:00')
 
     # Convert to given output type
     isyr2 = int(ptime.asctime()[-2:])
-    odate = list()
+    odate = np.zeros_like(idate)
     for i, d in enumerate(idate):
         dd = d.strip()
         # analyse date
@@ -321,18 +319,20 @@ def date2date(edate, fr=False, format='', timesep=' ', full=False):
                                  int(_leading_zero(dhour)),
                                  int(_leading_zero(dminute)),
                                  int(_leading_zero(dsecond)))
-            out = dattim.strftime(format)
-        odate.append(out)
+            # Assure 4 digit years on all platforms
+            # see https://bugs.python.org/issue32195
+            if '%Y' in format:
+                format04 = format.replace('%Y', '%04Y')
+                out = dattim.strftime(format04)
+                if '4Y' in out:
+                    out = dattim.strftime(format)
+            else:
+                out = dattim.strftime(format)
+        odate[i] = out
 
     # Return right type
-    if isinstance(edate, list):
-        return odate
-    elif isinstance(edate, tuple):
-        return tuple(odate)
-    elif isinstance(edate, np.ndarray):
-        return np.array(odate).reshape(edate.shape)
-    else:
-        return odate[0]
+    out = array2input(odate, edate, undef='')
+    return out
 
 
 def date2en(edate, **kwargs):
