@@ -5,112 +5,119 @@ Common functions used in scipy's curve_fit or minimize parameter estimations.
 For all fit functions, it defines the functions in two forms (ex. of 3
 params):
 
-    * `func(x, p1, p2, p3)`
-    * `func_p(x, p)` with `p[0:3]`
+.. code-block:: python
+
+   func(x, p1, p2, p3)
+   func_p(x, p) with p[0:3]
 
 The first form can be used, for example, with
 `scipy.optimize.curve_fit` (ex. function f1x=a+b/x):
 
-    * `p, cov = scipy.optimize.curve_fit(functions.f1x, x, y, p0=[p0, p1])`
+.. code-block:: python
+
+   p, cov = scipy.optimize.curve_fit(functions.f1x, x, y, p0=[p0, p1])
 
 It also defines two cost functions along with the fit functions, one
 with the absolute sum, one with the squared sum of the deviations:
 
-    * `cost_func`    `sum(abs(obs-func))`
-    * `cost2_func`   `sum((obs-func)**2)`
+.. code-block:: python
+
+   cost_func  = sum(abs(obs-func))
+   cost2_func = sum((obs-func)**2)
 
 These cost functions can be used, for example, with
 `scipy.optimize.minimize`:
 
-    * `p = scipy.optimize.minimize(
-      jams.functions.cost2_f1x,
-      np.array([p1, p2]),
-      args=(x, y),
-      method='Nelder-Mead',
-      options={'disp': False})`
+.. code-block:: python
+
+   p = scipy.optimize.minimize(
+           jams.functions.cost2_f1x, np.array([p1, p2]), args=(x, y),
+           method='Nelder-Mead', options={'disp': False})
 
 Note the different argument orders:
-
-    * `curvefit` needs `f(x, *p)` with the independent variable as the first
-      argument and the parameters to fit as separate remaining arguments.
-    * `minimize` is a general minimiser with respect to the first argument,
-      i.e. `func(p, *args)`.
+    1. `curvefit` needs `f(x, *p)` with the independent variable as the first
+       argument and the parameters to fit as separate remaining arguments.
+    2. `minimize` is a general minimiser with respect to the first argument,
+       i.e. `func(p, *args)`.
 
 The module provides also two common cost functions (absolute and
 squared deviations) where any function in the form `func(x, p)` can be
 used as second argument:
 
-    * `cost_abs(p, func, x, y)`
-    * `cost_square(p, func, x, y)`
+.. code-block:: python
+
+   cost_abs(p, func, x, y)
+   cost_square(p, func, x, y)
 
 This means, for example `cost_f1x(p, x, y)` is the same as
 `cost_abs(p, functions.f1x_p, x, y)`. For example:
 
-    * `p = scipy.optimize.minimize(
-      jams.functions.cost_abs,
-      np.array([p1, p2]),
-      args=(functions.f1x_p, x, y),
-      method='Nelder-Mead',
-      options={'disp': False})`
+.. code-block:: python
+
+   p = scipy.optimize.minimize(
+           jams.functions.cost_abs, np.array([p1, p2]),
+           args=(functions.f1x_p, x, y), method='Nelder-Mead',
+           options={'disp': False})
 
 There are the following functions in four forms. They have the name in the
 first column. The second form has a `_p` appended to the name. The cost
-functions have `cost_` or `cost2_` prepended to the name., e.g. gauss, gauss_p,
-cost_gauss, cost2_gauss:
+functions have `cost_` or `cost2_` prepended to the name, for example :func:`gauss`,
+:func:`gauss_p`, :func:`cost_gauss`, :func:`cost2_gauss`:
 
-    arrhenius - 1 param
-        Arrhenius temperature dependence of biochemical rates:
-        :math:`\exp((T-TC25)*E/(T25*R*(T+T0)))`
+.. list-table::
+   :widths: 15 50
+   :header-rows: 1
 
-        parameter: E
+   * - Function - number of paramters
+     - Description
 
-    f1x - 2 params
-       General 1/x function: :math:`a + b/x`
+   * - :func:`arrhenius`
+     - Arrhenius temperature dependence of biochemical rates:
+       :math:`\exp((T-TC25)*E/(T25*R*(T+T0)))`
 
-    fexp - 3 params
-       General exponential function: :math:`a + b * \exp(c*x)`
+   * - :func:`f1x`
+     - General 1/x function: :math:`a + b/x`
 
-    gauss - 2 params
-       Gauss function:
+   * - :func:`fexp`
+     - General exponential function: :math:`a + b * \exp(c*x)`
+
+   * - :func:`gauss`
+     - Gauss function:
        :math:`1/(\sigma*\sqrt(2*\pi)) * \exp(-(x-\mu)^2/(2*\sigma^2))`
 
-    lasslop - 6 params
-       Lasslop et al. (2010) is a rectangular, hyperbolic light-response GPP
-       with Lloyd & Taylor (1994) respiration and the maximum canopy uptake
-       rate at light saturation decreases exponentially with VPD
-       as in Koerner (1995).
+   * - :func:`lasslop`
+     - NEE of Lasslop et al. (2010)
 
-    line0 - 1 params
-       Straight line: :math:`a*x`
+   * - :func:`line0`
+     - Straight line: :math:`a*x`
 
-    line - 2 params
-       Straight line: :math:`a + b*x`
+   * - :func:`line`
+     - Straight line: :math:`a + b*x`
 
-    lloyd_fix - 2 params
-       Lloyd & Taylor (1994) Arrhenius type with :math:`T_0=-46.02` degC and
-       :math:`T_{ref}=10` degC
+   * - :func:`lloyd_fix`
+     - Heterotrophic respiration of Lloyd & Taylor (1994)
 
-    lloyd_only_rref - 1 param
-       Lloyd & Taylor (1994) Arrhenius type with fixed exponential term
+   * - :func:`lloyd_only_rref`
+     - Heterotrophic respiration of Lloyd & Taylor (1994) with fixed E0
 
-    logistic - 3 params
-       Logistic function: :math:`a/(1+\exp(-b(x-c)))`
+   * - :func:`logistic`
+     - Logistic function: :math:`a/(1+\exp(-b(x-c)))`
 
-    logistic_offset - 4 params
-       Logistic function with offset: :math:`a/(1+\exp(-b(x-c))) + d`
+   * - :func:`logistic_offset`
+     - Logistic function with offset: :math:`a/(1+\exp(-b(x-c))) + d`
 
-    logistic2_offset - 7 params
-       Double logistic function with offset
+   * - :func:`logistic2_offset`
+     - Double logistic function with offset
        :math:`L1/(1+\exp(-k1(x-x01))) - L2/(1+\exp(-k2(x-x02))) + a`
 
-    poly - n params
-       General polynomial: :math:`c_0 + c_1*x + c_2*x^2 + ... + c_n*x^n`
+   * - :func:`poly`
+     - General polynomial: :math:`c_0 + c_1*x + c_2*x^2 + ... + c_n*x^n`
 
-    sabx - 2 params
-       sqrt(f1x), i.e. general sqrt(1/x) function: :math:`\sqrt(a + b/x)`
+   * - :func:`sabx`
+     - sqrt(f1x), i.e. general sqrt(1/x) function: :math:`\sqrt(a + b/x)`
 
-    see - 3 params
-       Sequential Elementary Effects fitting function: :math:`a*(x-b)^c`
+   * - :func:`see`
+     - Sequential Elementary Effects fitting function: :math:`a*(x-b)^c`
 
 This module was written by Matthias Cuntz while at Department of
 Computational Hydrosystems, Helmholtz Centre for Environmental
@@ -118,7 +125,7 @@ Research - UFZ, Leipzig, Germany, and continued while at Institut
 National de Recherche pour l'Agriculture, l'Alimentation et
 l'Environnement (INRAE), Nancy, France.
 
-:copyright: Copyright 2012-2021 Matthias Cuntz, see AUTHORS.rst for details.
+:copyright: Copyright 2012-2022 Matthias Cuntz, see AUTHORS.rst for details.
 :license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
@@ -186,11 +193,12 @@ Functions:
 History
     * Written Dec 2012 by Matthias Cuntz (mc (at) macu (dot) de)
     * Ported to Python 3, Feb 2013, Matthias Cuntz
-    * Added general cost functions cost_abs and cost_square,
+    * Added general cost functions `cost_abs` and `cost_square`,
       May 2013, Matthias Cuntz
     * Added line0, Feb 2014, Matthias Cuntz
-    * Removed multiline_p, May 2020, Matthias Cuntz
+    * Removed `multiline_p`, May 2020, Matthias Cuntz
     * Changed to Sphinx docstring and numpydoc, May 2020, Matthias Cuntz
+    * More consistent docstrings, Jan 2022, Matthias Cuntz
 
 """
 from __future__ import division, absolute_import, print_function
@@ -238,7 +246,7 @@ __all__ = ['cost_abs', 'cost_square',
 # general cost functions
 def cost_abs(p, func, x, y):
     """
-    General cost function for robust optimising `func(x, p)` vs. `y` with sum
+    General cost function for robust optimising `func(x, p)` vs `y` with sum
     of absolute deviations.
 
     Parameters
@@ -262,7 +270,7 @@ def cost_abs(p, func, x, y):
 
 def cost_square(p, func, x, y):
     """
-    General cost function for optimising `func(x, p)` vs. `y` with sum of
+    General cost function for optimising `func(x, p)` vs `y` with sum of
     square deviations.
 
     Parameters
@@ -288,7 +296,7 @@ def cost_square(p, func, x, y):
 # arrhenius
 def arrhenius(T, E):
     """
-    Arrhenius temperature dependence of rates.
+    Arrhenius temperature dependence of rates
 
     Parameters
     ----------
@@ -307,14 +315,14 @@ def arrhenius(T, E):
 
 def arrhenius_p(T, p):
     """
-    Arrhenius temperature dependence of rates.
+    Arrhenius temperature dependence of rates
 
     Parameters
     ----------
     T : float or array_like of floats
         temperature [degC]
     p : iterable
-        `p[0]` is activation energy [J]
+        `p[0]` = activation energy [J]
 
     Returns
     -------
@@ -326,12 +334,12 @@ def arrhenius_p(T, p):
 
 def cost_arrhenius(p, T, rate):
     """
-    Sum of absolute deviations of obs and arrhenius function.
+    Sum of absolute deviations of obs and arrhenius function
 
     Parameters
     ----------
     p : iterable of floats
-        `p[0]` is activation energy [J]
+        `p[0]` = activation energy [J]
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -347,12 +355,12 @@ def cost_arrhenius(p, T, rate):
 
 def cost2_arrhenius(p, T, rate):
     """
-    Sum of squared deviations of obs and arrhenius function.
+    Sum of squared deviations of obs and arrhenius function
 
     Parameters
     ----------
     p : iterable of floats
-        `p[0]` is activation energy [J]
+        `p[0]` = activation energy [J]
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -370,7 +378,7 @@ def cost2_arrhenius(p, T, rate):
 # a+b/x
 def f1x(x, a, b):
     """
-    General 1/x function: a + b/x
+    General 1/x function: :math:`a + b/x`
 
     Parameters
     ----------
@@ -391,7 +399,7 @@ def f1x(x, a, b):
 
 def f1x_p(x, p):
     """
-    General 1/x function: a + b/x
+    General 1/x function: :math:`a + b/x`
 
     Parameters
     ----------
@@ -399,10 +407,8 @@ def f1x_p(x, p):
         independent variable
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
 
     Returns
     -------
@@ -414,16 +420,14 @@ def f1x_p(x, p):
 
 def cost_f1x(p, x, y):
     """
-    Sum of absolute deviations of obs and general 1/x function: a + b/x
+    Sum of absolute deviations of obs and general 1/x function: :math:`a + b/x`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -439,16 +443,14 @@ def cost_f1x(p, x, y):
 
 def cost2_f1x(p, x, y):
     """
-    Sum of squared deviations of obs and general 1/x function: a + b/x
+    Sum of squared deviations of obs and general 1/x function: :math:`a + b/x`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -466,7 +468,7 @@ def cost2_f1x(p, x, y):
 # a+b*exp(c*x)
 def fexp(x, a, b, c):
     """
-    General exponential function: a + b * exp(c*x)
+    General exponential function: :math:`a + b * exp(c*x)`
 
     Parameters
     ----------
@@ -489,7 +491,7 @@ def fexp(x, a, b, c):
 
 def fexp_p(x, p):
     """
-    General exponential function: a + b * exp(c*x)
+    General exponential function: :math:`a + b * exp(c*x)`
 
     Parameters
     ----------
@@ -497,12 +499,9 @@ def fexp_p(x, p):
         independent variable
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` a
-
-        `p[1]` b
-
-        `p[2]` c
+          - `p[0]` = a
+          - `p[1]` = b
+          - `p[2]` = c
 
     Returns
     -------
@@ -514,19 +513,16 @@ def fexp_p(x, p):
 
 def cost_fexp(p, x, y):
     """
-    Sum of absolute deviations of obs and general exponential function: a + b *
-    exp(c*x)
+    Sum of absolute deviations of obs and general exponential function:
+    :math:`a + b * exp(c*x)`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` a
-
-        `p[1]` b
-
-        `p[2]` c
+          - `p[0]` = a
+          - `p[1]` = b
+          - `p[2]` = c
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -543,18 +539,15 @@ def cost_fexp(p, x, y):
 def cost2_fexp(p, x, y):
     """
     Sum of squared deviations of obs and general exponential function:
-    a + b * exp(c*x)
+    :math:`a + b * exp(c*x)`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` a
-
-        `p[1]` b
-
-        `p[2]` c
+          - `p[0]` = a
+          - `p[1]` = b
+          - `p[2]` = c
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -572,7 +565,8 @@ def cost2_fexp(p, x, y):
 # Gauss: 1/(sig*sqrt(2*pi)) *exp(-(x-mu)**2/(2*sig**2))
 def gauss(x, mu, sig):
     """
-    Gauss function: 1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )
+    Gauss function:
+    :math:`1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )`
 
     Parameters
     ----------
@@ -593,7 +587,8 @@ def gauss(x, mu, sig):
 
 def gauss_p(x, p):
     """
-    Gauss function: 1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )
+    Gauss function:
+    :math:`1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )`
 
     Parameters
     ----------
@@ -601,10 +596,8 @@ def gauss_p(x, p):
         independent variable
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` mean mu
-
-        `p[1]` width sig
+          - `p[0]` = mean mu
+          - `p[1]` = width sig
 
     Returns
     -------
@@ -617,16 +610,14 @@ def gauss_p(x, p):
 def cost_gauss(p, x, y):
     """
     Sum of absolute deviations of obs and Gauss function:
-    1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )
+    :math:`1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` mean
-
-        `p[1]` width
+          - `p[0]` = mean mu
+          - `p[1]` = width sig
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -643,16 +634,14 @@ def cost_gauss(p, x, y):
 def cost2_gauss(p, x, y):
     """
     Sum of squared deviations of obs and Gauss function:
-    1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )
+    :math:`1 / (sqrt(2*pi)*sig) * exp( -(x-mu)**2 / (2*sig**2) )`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` mean
-
-        `p[1]` width
+          - `p[0]` = mean mu
+          - `p[1]` = width sig
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -670,6 +659,8 @@ def cost2_gauss(p, x, y):
 # lasslop
 def lasslop(Rg, et, VPD, alpha, beta0, k, Rref):
     """
+    NEE of Lasslop et al (2010)
+
     Lasslop et al. (2010) is the rectangular, hyperbolic light-response
     of NEE as by Falge et al. (2001), where the respiration is calculated
     with Lloyd & Taylor (1994), and the maximum canopy uptake rate at
@@ -710,6 +701,8 @@ def lasslop(Rg, et, VPD, alpha, beta0, k, Rref):
 
 def lasslop_p(Rg, et, VPD, p):
     """
+    NEE of Lasslop et al (2010)
+
     Lasslop et al. (2010) is the rectangular, hyperbolic light-response
     of NEE as by Falge et al. (2001), where the respiration is calculated
     with Lloyd & Taylor (1994), and the maximum canopy uptake rate at
@@ -725,16 +718,12 @@ def lasslop_p(Rg, et, VPD, p):
         Vapour Pressure Deficit [Pa]
     p : iterable of floats
         parameters (`len(p)=4`)
-
-        `p[0]` Light use efficiency, i.e. initial slope of light response curve
-               [umol(C) J-1]
-
-        `p[1]` Maximum CO2 uptake rate at VPD0=10 hPa [umol(C) m-2 s-1]
-
-        `p[2]` e-folding of exponential decrease of maximum CO2 uptake with
-               VPD increase [Pa-1]
-
-        `p[3]` Respiration at Tref (10 degC) [umol(C) m-2 s-1]
+          - `p[0]` = Light use efficiency, i.e. initial slope of light response
+            curve [umol(C) J-1]
+          - `p[1]` = Maximum CO2 uptake rate at VPD0=10 hPa [umol(C) m-2 s-1]
+          - `p[2]` = e-folding of exponential decrease of maximum CO2 uptake
+            with VPD increase [Pa-1]
+          - `p[3]` = Respiration at Tref (10 degC) [umol(C) m-2 s-1]
 
     Returns
     -------
@@ -752,22 +741,18 @@ def lasslop_p(Rg, et, VPD, p):
 
 def cost_lasslop(p, Rg, et, VPD, NEE):
     """
-    Sum of absolute deviations of obs and Lasslop.
+    Sum of absolute deviations of obs and Lasslop et al (2010)
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=4`)
-
-        `p[0]` Light use efficiency, i.e. initial slope of light response curve
-               [umol(C) J-1]
-
-        `p[1]` Maximum CO2 uptake rate at VPD0=10 hPa [umol(C) m-2 s-1]
-
-        `p[2]` e-folding of exponential decrease of maximum CO2 uptake with
-               VPD increase [Pa-1]
-
-        `p[3]` Respiration at Tref (10 degC) [umol(C) m-2 s-1]
+          - `p[0]` = Light use efficiency, i.e. initial slope of light response
+            curve [umol(C) J-1]
+          - `p[1]` = Maximum CO2 uptake rate at VPD0=10 hPa [umol(C) m-2 s-1]
+          - `p[2]` = e-folding of exponential decrease of maximum CO2 uptake
+            with VPD increase [Pa-1]
+          - `p[3]` = Respiration at Tref (10 degC) [umol(C) m-2 s-1]
     Rg : float or array_like of floats
         Global radiation [W m-2]
     et : float or array_like of floats
@@ -787,22 +772,18 @@ def cost_lasslop(p, Rg, et, VPD, NEE):
 
 def cost2_lasslop(p, Rg, et, VPD, NEE):
     """
-    Sum of squared deviations of obs and Lasslop.
+    Sum of squared deviations of obs and Lasslop et al (2010)
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=4`)
-
-        `p[0]` Light use efficiency, i.e. initial slope of light response curve
-               [umol(C) J-1]
-
-        `p[1]` Maximum CO2 uptake rate at VPD0=10 hPa [umol(C) m-2 s-1]
-
-        `p[2]` e-folding of exponential decrease of maximum CO2 uptake with
-               VPD increase [Pa-1]
-
-        `p[3]` Respiration at Tref (10 degC) [umol(C) m-2 s-1]
+          - `p[0]` = Light use efficiency, i.e. initial slope of light response
+            curve [umol(C) J-1]
+          - `p[1]` = Maximum CO2 uptake rate at VPD0=10 hPa [umol(C) m-2 s-1]
+          - `p[2]` = e-folding of exponential decrease of maximum CO2 uptake
+            with VPD increase [Pa-1]
+          - `p[3]` = Respiration at Tref (10 degC) [umol(C) m-2 s-1]
     Rg : float or array_like of floats
         Global radiation [W m-2]
     et : float or array_like of floats
@@ -824,7 +805,7 @@ def cost2_lasslop(p, Rg, et, VPD, NEE):
 # a+b*x
 def line(x, a, b):
     """
-    Straight line: a + b*x
+    Straight line: :math:`a + b*x`
 
     Parameters
     ----------
@@ -845,7 +826,7 @@ def line(x, a, b):
 
 def line_p(x, p):
     """
-    Straight line: a + b*x
+    Straight line: :math:`a + b*x`
 
     Parameters
     ----------
@@ -853,10 +834,8 @@ def line_p(x, p):
         independent variable
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
 
     Returns
     -------
@@ -868,16 +847,14 @@ def line_p(x, p):
 
 def cost_line(p, x, y):
     """
-    Sum of absolute deviations of obs and straight line: a + b*x
+    Sum of absolute deviations of obs and straight line: :math:`a + b*x`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -893,16 +870,14 @@ def cost_line(p, x, y):
 
 def cost2_line(p, x, y):
     """
-    Sum of squared deviations of obs and straight line: a + b*x
+    Sum of squared deviations of obs and straight line: :math:`a + b*x`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -920,7 +895,7 @@ def cost2_line(p, x, y):
 # b*x
 def line0(x, a):
     """
-    Straight line through origin: a*x
+    Straight line through origin: :math:`a*x`
 
     Parameters
     ----------
@@ -939,14 +914,14 @@ def line0(x, a):
 
 def line0_p(x, p):
     """
-    Straight line through origin: a*x
+    Straight line through origin: :math:`a*x`
 
     Parameters
     ----------
     x : float or array_like of floats
         independent variable
     p : iterable of floats
-        `p[0]` is a
+        `p[0]` = a
 
     Returns
     -------
@@ -958,12 +933,13 @@ def line0_p(x, p):
 
 def cost_line0(p, x, y):
     """
-    Sum of absolute deviations of obs and straight line through origin: a*x
+    Sum of absolute deviations of obs and straight line through origin:
+    :math:`a*x`
 
     Parameters
     ----------
     p : iterable of floats
-        `p[0]` is a
+        `p[0]` = a
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -979,12 +955,13 @@ def cost_line0(p, x, y):
 
 def cost2_line0(p, x, y):
     """
-    Sum of squared deviations of obs and straight line through origin: a*x
+    Sum of squared deviations of obs and straight line through origin:
+    :math:`a*x`
 
     Parameters
     ----------
     p : iterable of floats
-        `p[0]` is a
+        `p[0]` = a
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1002,6 +979,8 @@ def cost2_line0(p, x, y):
 # lloyd_fix
 def lloyd_fix(T, Rref, E0):
     """
+    Soil respiration of Lloyd & Taylor (1994)
+
     Lloyd & Taylor (1994) Arrhenius type with T0=-46.02 degC and Tref=10 degC
 
     Parameters
@@ -1025,6 +1004,8 @@ def lloyd_fix(T, Rref, E0):
 
 def lloyd_fix_p(T, p):
     """
+    Soil respiration of Lloyd & Taylor (1994)
+
     Lloyd & Taylor (1994) Arrhenius type with T0=-46.02 degC and Tref=10 degC
 
     Parameters
@@ -1033,10 +1014,8 @@ def lloyd_fix_p(T, p):
         Temperature [K]
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` Respiration at Tref=10 degC [umol(C) m-2 s-1]
-
-        `p[1]` Activation energy [K]
+          - `p[0]` = Respiration at Tref=10 degC [umol(C) m-2 s-1]
+          - `p[1]` = Activation energy [K]
 
     Returns
     -------
@@ -1056,10 +1035,8 @@ def cost_lloyd_fix(p, T, resp):
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` Respiration at Tref=10 degC [umol(C) m-2 s-1]
-
-        `p[1]` Activation energy [K]
+          - `p[0]` = Respiration at Tref=10 degC [umol(C) m-2 s-1]
+          - `p[1]` = Activation energy [K]
     T : float or array_like of floats
         Temperature [K]
     resp : float or array_like of floats
@@ -1081,10 +1058,8 @@ def cost2_lloyd_fix(p, T, resp):
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` Respiration at Tref=10 degC [umol(C) m-2 s-1]
-
-        `p[1]` Activation energy [K]
+          - `p[0]` = Respiration at Tref=10 degC [umol(C) m-2 s-1]
+          - `p[1]` = Activation energy [K]
     T : float or array_like of floats
         Temperature [K]
     resp : float or array_like of floats
@@ -1102,6 +1077,8 @@ def cost2_lloyd_fix(p, T, resp):
 # lloyd_only_rref
 def lloyd_only_rref(et, Rref):
     """
+    Soil respiration of Lloyd & Taylor (1994) with fix E0
+
     If E0 is know in Lloyd & Taylor (1994) then one can calc
     the exponential term outside the routine and the fitting
     becomes linear. One could also use functions.line0.
@@ -1123,6 +1100,8 @@ def lloyd_only_rref(et, Rref):
 
 def lloyd_only_rref_p(et, p):
     """
+    Soil respiration of Lloyd & Taylor (1994) with fix E0
+
     If E0 is know in Lloyd & Taylor (1994) then one can calc
     the exponential term outside the routine and the fitting
     becomes linear. One could also use functions.line0.
@@ -1132,7 +1111,7 @@ def lloyd_only_rref_p(et, p):
     et : float or array_like of floats
         exp-term in Lloyd & Taylor
     p : iterable of floats
-        `p[0]` is respiration at Tref=10 degC [umol(C) m-2 s-1]
+        `p[0]` = Respiration at Tref=10 degC [umol(C) m-2 s-1]
 
     Returns
     -------
@@ -1144,13 +1123,12 @@ def lloyd_only_rref_p(et, p):
 
 def cost_lloyd_only_rref(p, et, resp):
     """
-    Sum of absolute deviations of obs and Lloyd & Taylor with known exponential
-    term.
+    Sum of absolute deviations of obs and Lloyd & Taylor with fixed E0
 
     Parameters
     ----------
     p : iterable of floats
-        `p[0]` is respiration at Tref=10 degC [umol(C) m-2 s-1]
+        `p[0]` = Respiration at Tref=10 degC [umol(C) m-2 s-1]
     et : float or array_like of floats
         exp-term in Lloyd & Taylor
     resp : float or array_like of floats
@@ -1166,13 +1144,12 @@ def cost_lloyd_only_rref(p, et, resp):
 
 def cost2_lloyd_only_rref(p, et, resp):
     """
-    Sum of squared deviations of obs and Lloyd & Taylor with known exponential
-    term.
+    Sum of squared deviations of obs and Lloyd & Taylor with fixed E0
 
     Parameters
     ----------
     p : iterable of floats
-        `p[0]` is respiration at Tref=10 degC [umol(C) m-2 s-1]
+        `p[0]` = Respiration at Tref=10 degC [umol(C) m-2 s-1]
     et : float or array_like of floats
         exp-term in Lloyd & Taylor
     resp : float or array_like of floats
@@ -1191,7 +1168,7 @@ def cost2_lloyd_only_rref(p, et, resp):
 
 def sabx(x, a, b):
     """
-    Square root of general 1/x function: sqrt(a + b/x)
+    Square root of general 1/x function: :math:`sqrt(a + b/x)`
 
     Parameters
     ----------
@@ -1212,7 +1189,7 @@ def sabx(x, a, b):
 
 def sabx_p(x, p):
     """
-    Square root of general 1/x function: sqrt(a + b/x)
+    Square root of general 1/x function: :math:`sqrt(a + b/x)`
 
     Parameters
     ----------
@@ -1220,10 +1197,8 @@ def sabx_p(x, p):
         independent variable
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
 
     Returns
     -------
@@ -1236,16 +1211,14 @@ def sabx_p(x, p):
 def cost_sabx(p, x, y):
     """
     Sum of absolute deviations of obs and square root of general 1/x function:
-    sqrt(a + b/x)
+    :math:`sqrt(a + b/x)`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1262,16 +1235,14 @@ def cost_sabx(p, x, y):
 def cost2_sabx(p, x, y):
     """
     Sum of squared deviations of obs and square root of general 1/x function:
-    sqrt(a + b/x)
+    :math:`sqrt(a + b/x)`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=2`)
-
-        `p[0]` a
-
-        `p[1]` b
+          - `p[0]` = a
+          - `p[1]` = b
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1289,7 +1260,7 @@ def cost2_sabx(p, x, y):
 # c0 + c1*x + c2*x**2 + ... + cn*x**n
 def poly(x, *args):
     """
-    General polynomial: c0 + c1*x + c2*x**2 + ... + cn*x**n
+    General polynomial: :math:`c0 + c1*x + c2*x**2 + ... + cn*x**n`
 
     Parameters
     ----------
@@ -1308,7 +1279,7 @@ def poly(x, *args):
 
 def poly_p(x, p):
     """
-    General polynomial: c0 + c1*x + c2*x**2 + ... + cn*x**n
+    General polynomial: :math:`c0 + c1*x + c2*x**2 + ... + cn*x**n`
 
     Parameters
     ----------
@@ -1328,7 +1299,7 @@ def poly_p(x, p):
 def cost_poly(p, x, y):
     """
     Sum of absolute deviations of obs and general polynomial:
-    c0 + c1*x + c2*x**2 + ... + cn*x**n
+    :math:`c0 + c1*x + c2*x**2 + ... + cn*x**n`
 
     Parameters
     ----------
@@ -1350,7 +1321,7 @@ def cost_poly(p, x, y):
 def cost2_poly(p, x, y):
     """
     Sum of squared deviations of obs and general polynomial:
-    c0 + c1*x + c2*x**2 + ... + cn*x**n
+    :math:`c0 + c1*x + c2*x**2 + ... + cn*x**n`
 
     Parameters
     ----------
@@ -1373,18 +1344,16 @@ def cost2_poly(p, x, y):
 # a/(1+exp(-b(x-c))) - logistic function
 def cost_logistic(p, x, y):
     """
-    Sum of absolute deviations of obs and logistic function L/(1+exp(-k(x-x0)))
+    Sum of absolute deviations of obs and logistic function
+    :math:`L/(1+exp(-k(x-x0)))`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` L  - Maximum of logistic function
-
-        `p[1]` k  - Steepness of logistic function
-
-        `p[2]` x0 - Inflection point of logistic function
+          - `p[0]` = L  = Maximum of logistic function
+          - `p[1]` = k  = Steepness of logistic function
+          - `p[2]` = x0 = Inflection point of logistic function
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1400,18 +1369,16 @@ def cost_logistic(p, x, y):
 
 def cost2_logistic(p, x, y):
     """
-    Sum of squared deviations of obs and logistic function L/(1+exp(-k(x-x0)))
+    Sum of squared deviations of obs and logistic function
+    :math:`L/(1+exp(-k(x-x0)))`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` L  - Maximum of logistic function
-
-        `p[1]` k  - Steepness of logistic function
-
-        `p[2]` x0 - Inflection point of logistic function
+          - `p[0]` = L  = Maximum of logistic function
+          - `p[1]` = k  = Steepness of logistic function
+          - `p[2]` = x0 = Inflection point of logistic function
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1430,20 +1397,16 @@ def cost2_logistic(p, x, y):
 def cost_logistic_offset(p, x, y):
     """
     Sum of absolute deviations of obs and logistic function 1/x function:
-    L/(1+exp(-k(x-x0))) + a
+    :math:`L/(1+exp(-k(x-x0))) + a`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=4`)
-
-        `p[0]` L  - Maximum of logistic function
-
-        `p[1]` k  - Steepness of logistic function
-
-        `p[2]` x0 - Inflection point of logistic function
-
-        `p[3]` a  - Offset of logistic function
+          - `p[0]` = L  = Maximum of logistic function
+          - `p[1]` = k  = Steepness of logistic function
+          - `p[2]` = x0 = Inflection point of logistic function
+          - `p[3]` = a  = Offset of logistic function
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1460,20 +1423,16 @@ def cost_logistic_offset(p, x, y):
 def cost2_logistic_offset(p, x, y):
     """
     Sum of squared deviations of obs and logistic function 1/x function:
-    L/(1+exp(-k(x-x0))) + a
+    :math:`L/(1+exp(-k(x-x0))) + a`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=4`)
-
-        `p[0]` L  - Maximum of logistic function
-
-        `p[1]` k  - Steepness of logistic function
-
-        `p[2]` x0 - Inflection point of logistic function
-
-        `p[3]` a  - Offset of logistic function
+          - `p[0]` = L  = Maximum of logistic function
+          - `p[1]` = k  = Steepness of logistic function
+          - `p[2]` = x0 = Inflection point of logistic function
+          - `p[3]` = a  = Offset of logistic function
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1493,26 +1452,19 @@ def cost2_logistic_offset(p, x, y):
 def cost_logistic2_offset(p, x, y):
     """
     Sum of absolute deviations of obs and double logistic function with offset:
-    L1/(1+exp(-k1(x-x01))) - L2/(1+exp(-k2(x-x02))) + a
+    :math:`L1/(1+exp(-k1(x-x01))) - L2/(1+exp(-k2(x-x02))) + a`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=7`)
-
-        `p[0]` L1  - Maximum of first logistic function
-
-        `p[1]` k1  - Steepness of first logistic function
-
-        `p[2]` x01 - Inflection point of first logistic function
-
-        `p[3]` L2  - Maximum of second logistic function
-
-        `p[4]` k2  - Steepness of second logistic function
-
-        `p[5]` x02 - Inflection point of second logistic function
-
-        `p[6]` a   - Offset of double logistic function
+          - `p[0]` = L1  = Maximum of first logistic function
+          - `p[1]` = k1  = Steepness of first logistic function
+          - `p[2]` = x01 = Inflection point of first logistic function
+          - `p[3]` = L2  = Maximum of second logistic function
+          - `p[4]` = k2  = Steepness of second logistic function
+          - `p[5]` = x02 = Inflection point of second logistic function
+          - `p[6]` = a  = Offset of double logistic function
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1529,26 +1481,19 @@ def cost_logistic2_offset(p, x, y):
 def cost2_logistic2_offset(p, x, y):
     """
     Sum of squared deviations of obs and double logistic function with offset:
-    L1/(1+exp(-k1(x-x01))) - L2/(1+exp(-k2(x-x02))) + a
+    :math:`L1/(1+exp(-k1(x-x01))) - L2/(1+exp(-k2(x-x02))) + a`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=7`)
-
-        `p[0]` L1  - Maximum of first logistic function
-
-        `p[1]` k1  - Steepness of first logistic function
-
-        `p[2]` x01 - Inflection point of first logistic function
-
-        `p[3]` L2  - Maximum of second logistic function
-
-        `p[4]` k2  - Steepness of second logistic function
-
-        `p[5]` x02 - Inflection point of second logistic function
-
-        `p[6]` a   - Offset of double logistic function
+          - `p[0]` = L1  = Maximum of first logistic function
+          - `p[1]` = k1  = Steepness of first logistic function
+          - `p[2]` = x01 = Inflection point of first logistic function
+          - `p[3]` = L2  = Maximum of second logistic function
+          - `p[4]` = k2  = Steepness of second logistic function
+          - `p[5]` = x02 = Inflection point of second logistic function
+          - `p[6]` = a  = Offset of double logistic function
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1566,7 +1511,7 @@ def cost2_logistic2_offset(p, x, y):
 # a*(x-b)**c - Sequential Elementary Effects fitting function
 def see(x, a, b, c):
     """
-    Fit function of Sequential Elementary Effects: a * (x-b)**c
+    Fit function of Sequential Elementary Effects: :math:`a * (x-b)**c`
 
     Parameters
     ----------
@@ -1589,7 +1534,7 @@ def see(x, a, b, c):
 
 def see_p(x, p):
     """
-    Fit function of Sequential Elementary Effects: a * (x-b)**c
+    Fit function of Sequential Elementary Effects: :math:`a * (x-b)**c`
 
     Parameters
     ----------
@@ -1597,12 +1542,9 @@ def see_p(x, p):
         independent variable
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` a
-
-        `p[1]` b
-
-        `p[2]` c
+          - `p[0]` = a
+          - `p[1]` = b
+          - `p[2]` = c
 
     Returns
     -------
@@ -1615,18 +1557,15 @@ def see_p(x, p):
 def cost_see(p, x, y):
     """
     Sum of absolute deviations of obs and fit function of Sequential Elementary
-    Effects: a * (x-b)**c
+    Effects: :math:`a * (x-b)**c`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` a
-
-        `p[1]` b
-
-        `p[2]` c
+          - `p[0]` = a
+          - `p[1]` = b
+          - `p[2]` = c
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
@@ -1643,18 +1582,15 @@ def cost_see(p, x, y):
 def cost2_see(p, x, y):
     """
     Sum of squared deviations of obs and fit function of Sequential Elementary
-    Effects: a * (x-b)**c
+    Effects: :math:`a * (x-b)**c`
 
     Parameters
     ----------
     p : iterable of floats
         parameters (`len(p)=3`)
-
-        `p[0]` a
-
-        `p[1]` b
-
-        `p[2]` c
+          - `p[0]` = a
+          - `p[1]` = b
+          - `p[2]` = c
     x : float or array_like of floats
         independent variable
     y : float or array_like of floats
