@@ -18,7 +18,7 @@ The simplest way to use mcPlot is to extend the class:
 .. code-block:: python
 
    import numpy as np
-   from jams import mcPlot
+   from pyjams import mcPlot
 
    class PlotIt(mcPlot):
        def __init__(self, *args, **kwargs):
@@ -70,11 +70,12 @@ The simplest way to use mcPlot is to extend the class:
 
 Then call the script with -h to see the command line options.
 
+
 This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-:copyright: Copyright 2020-2021 Matthias Cuntz, see AUTHORS.rst for details.
+:copyright: Copyright 2020-2022 Matthias Cuntz, see AUTHORS.rst for details.
 :license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
@@ -87,6 +88,11 @@ The following classes are provided:
 History
     * Written Sep 2020 by Matthias Cuntz (mc (at) macu (dot) de)
     * Write standard output file into current folder, Nov 2021, Matthias Cuntz
+    * Change from NCL amwg color palette to pyjams amwg,
+      May 2021, Matthias Cuntz
+    * Add **kwargs to plot_save, May 2022, Matthias Cuntz
+    * Add self.transparent to pdf output in plot_save, May 2022, Matthias Cuntz
+    * Add --transparent as a standard option, May 2022, Matthias Cuntz
 
 """
 import numpy as np
@@ -146,7 +152,7 @@ class mcPlot(object):
         it to its needs, keeping the existing optional arguments.
     plot_end() or plot_stop() or or plot_close() or end() or stop()
         Finish, closing opened output files.
-    plot_save(fig)
+    plot_save(fig, **kwargs)
         Save, close or show `figure`.
     set_layout_options()
         Sets the colours and styles that can be used in plots.
@@ -180,7 +186,7 @@ class mcPlot(object):
     .. code-block:: python
 
        import numpy as np
-       from jams import mcPlot
+       from pyjams import mcPlot
 
        class PlotIt(mcPlot):
            def __init__(self, *args, **kwargs):
@@ -306,6 +312,8 @@ class mcPlot(object):
              -t outtype, --type outtype
                                    Output type is pdf, png, html, d3, or plotly
                                    (default: open screen windows).
+             --transparent         Transparent figure background
+                                   (default: black or white).
              -u, --usetex          Use LaTeX to render text in pdf, png and
                                    html.
              -w, --white           White lines on transparent or black
@@ -335,29 +343,34 @@ class mcPlot(object):
         plotname = ''
         serif    = False
         outtype  = ''
+        transparent = False
         usetex   = False
         dowhite  = False
         parser   = argparse.ArgumentParser(
             formatter_class=argparse.RawDescriptionHelpFormatter,
             description=idesc)
-        hstr  = 'Name of plot output file for types pdf, html, d3, or'
-        hstr += ' plotly, and name basis for type png (default:'
-        hstr += ' ' + _filebase(os.path.basename(__file__)) + ').'
+        default = _filebase(os.path.basename(__file__))
+        hstr = (f'Name of plot output file for types pdf, html, d3, or'
+                f' plotly, and name basis for type png (default:'
+                f' {default}).')
         parser.add_argument('-p', '--plotname', action='store',
                             default=plotname, dest='plotname',
                             metavar='plotname', help=hstr)
         hstr = 'Use serif font; default sans serif.'
         parser.add_argument('-s', '--serif', action='store_true',
                             default=serif, dest='serif', help=hstr)
-        hstr = 'Output type is pdf, png, html, d3, or plotly'
-        hstr = hstr + ' (default: open screen windows).'
+        hstr = ('Output type is pdf, png, html, d3, or plotly'
+                ' (default: open screen windows).')
         parser.add_argument('-t', '--type', action='store', default=outtype,
                             dest='outtype', metavar='outtype', help=hstr)
+        hstr = ('Transparent figure background (default: black or white).')
+        parser.add_argument('--transparent', action='store_true',
+                            default=transparent, dest='transparent', help=hstr)
         hstr = 'Use LaTeX to render text in pdf, png and html.'
         parser.add_argument('-u', '--usetex', action='store_true',
                             default=usetex, dest='usetex', help=hstr)
-        hstr  = 'White lines on transparent or black background;'
-        hstr += ' default: black lines on transparent or white background.'
+        hstr = ('White lines on transparent or black background;'
+                ' default: black lines on transparent or white background.')
         parser.add_argument('-w', '--white', action='store_true',
                             default=dowhite, dest='dowhite', help=hstr)
         parser.add_argument('cargs', nargs='*', default=None,
@@ -365,12 +378,13 @@ class mcPlot(object):
 
         args = parser.parse_args()
 
-        self.args     = args.cargs
-        self.plotname = args.plotname
-        self.serif    = args.serif
-        self.outtype  = args.outtype
-        self.usetex   = args.usetex
-        self.dowhite  = args.dowhite
+        self.args        = args.cargs
+        self.plotname    = args.plotname
+        self.serif       = args.serif
+        self.outtype     = args.outtype
+        self.transparent = args.transparent
+        self.usetex      = args.usetex
+        self.dowhite     = args.dowhite
 
         del parser, args
 
@@ -514,28 +528,26 @@ class mcPlot(object):
         else:
             self.fgcolor = 'black'
             self.bgcolor = 'white'
-        # NCL's amwg colour map without the first three colours
+        # pyjams' amwg color map without the first three colours
         # white, black and purple
-        amwg = [(0., 0., 0.784),        # dark blue
-                (0.235, 0.392, 0.902),  # medium blue
-                (0.471, 0.608, 0.949),  # light blue
-                (0.69, 0.878, 0.902),   # cyan
-                (0.125, 0.698, 0.667),  # turquoise
-                (0.604, 0.804, 0.196),  # light green
-                (0.18, 0.545, 0.341),   # dark green
-                (0.961, 0.902, 0.745),  # sand
-                (0.871, 0.722, 0.529),  # beige
-                (1., 0.882, 0.),        # yellow
-                (1., 0.647, 0.),        # orange
-                (1., 0.271, 0.),        # light red
-                (0.698, 0.133, 0.133),  # dark red
-                (1., 0.714, 0.757),     # rose
-                (1., 0.078, 0.576)]     # pink
+        amwg = [(0.141, 0.129, 0.408),  # dark blue
+                (0.141, 0.357, 0.6),    # medium blue
+                (0.365, 0.533, 0.725),  # light blue
+                (0.608, 0.8, 0.835),    # cyan
+                (0.0, 0.596, 0.639),    # turquoise
+                (0.553, 0.725, 0.259),  # light green
+                (0.055, 0.518, 0.345),  # dark green
+                (0.937, 0.863, 0.714),  # sand
+                (0.808, 0.675, 0.51),   # beige
+                (0.957, 0.816, 0.169),  # yellow
+                (0.898, 0.6, 0.165),    # orange
+                (0.835, 0.294, 0.157),  # light red
+                (0.568, 0.176, 0.196)]  # dark red
         self.mcols = amwg
         self.mcol1 = self.mcols[0]   # dark blue
-        self.mcol2 = self.mcols[-3]  # dark red
+        self.mcol2 = self.mcols[12]  # dark red
         self.mcol3 = self.mcols[2]   # light blue
-        self.mcol4 = self.mcols[-4]  # orange
+        self.mcol4 = self.mcols[10]  # orange
         self.mcol5 = self.mcols[6]   # dark green
         self.lcol1 = self.mcol1
         self.lcol2 = self.mcol2
@@ -564,7 +576,6 @@ class mcPlot(object):
                                  # If None, use rc
         # png
         self.dpi         = 300
-        self.transparent = False
         self.bbox_inches = 'tight'
         self.pad_inches  = 0.035
 
@@ -872,40 +883,56 @@ class mcPlot(object):
     # -------------------------------------------------------------------------
     # plot save
     #
-    def plot_save(self, fig):
+    def plot_save(self, fig, **kwargs):
         """
         Save figure into output file
 
         Parameters
         ----------
         fig : matplotlib.figure.Figure
-            Matplotlib figure object.
+            Matplotlib figure object.    argstr : string, optional
+        kwargs : dict, optional
+            Additional keywords will be passed to *savefig* for 'pdf',
+            'png', and 'html'; to *fig_to_html* for 'd3', and to
+            *offline.plot* for 'plotly'. This overwrites *self.transparent*,
+            *self.bbox_inches*, *self.pad_inches* for 'pdf', 'png', and 'html',
+            and *auto_open=False* for 'plotly'.
 
         """
         import matplotlib.pyplot as plt
         # save pages
         if (self.outtype == 'pdf'):
-            self.pdf_pages.savefig(fig)
+            if 'transparent' not in kwargs:
+                kwargs.update({'transparent': self.transparent})
+            self.pdf_pages.savefig(fig, **kwargs)
             plt.close(fig)
         elif (self.outtype == 'png'):
             pngfile = self.plotfile+"{0:04d}".format(self.ifig)+".png"
-            fig.savefig(pngfile, transparent=self.transparent,
-                        bbox_inches=self.bbox_inches,
-                        pad_inches=self.pad_inches)
+            if 'transparent' not in kwargs:
+                kwargs.update({'transparent': self.transparent})
+            if 'bbox_inches' not in kwargs:
+                kwargs.update({'bbox_inches': self.bbox_inches})
+            if 'pad_inches' not in kwargs:
+                kwargs.update({'pad_inches': self.pad_inches})
+            fig.savefig(pngfile, **kwargs)
             plt.close(fig)
         elif (self.outtype == 'html'):
             pngfile  = _filebase(self.plotfile) + "_"
             pngfile += "{0:04d}".format(self.ifig) + ".png"
-            fig.savefig(pngfile, transparent=self.transparent,
-                        bbox_inches=self.bbox_inches,
-                        pad_inches=self.pad_inches)
+            if 'transparent' not in kwargs:
+                kwargs.update({'transparent': self.transparent})
+            if 'bbox_inches' not in kwargs:
+                kwargs.update({'bbox_inches': self.bbox_inches})
+            if 'pad_inches' not in kwargs:
+                kwargs.update({'pad_inches': self.pad_inches})
+            fig.savefig(pngfile, **kwargs)
             print('<p><img src='+pngfile+'></p>', file=self.fhtml)
             plt.close(fig)
         elif (self.outtype == 'd3'):
             import mpld3
             # Does not work:
             #     mpld3.plugins.connect(fig, mpld3.plugins.LinkedBrush(line1))
-            d3str = mpld3.fig_to_html(fig)
+            d3str = mpld3.fig_to_html(fig, **kwargs)
             print(d3str, file=self.fhtml)
             plt.close(fig)
         elif (self.outtype == 'plotly'):
@@ -913,8 +940,9 @@ class mcPlot(object):
             import plotly.offline
             htmlfile = self.plotfile+"{0:04d}".format(self.ifig)+".html"
             plotly_fig = plotly.tools.mpl_to_plotly(fig)
-            ff = plotly.offline.plot(plotly_fig, filename=htmlfile,
-                                     auto_open=False)
+            if 'auto_open' not in kwargs:
+                kwargs.update({'auto_open': False})
+            ff = plotly.offline.plot(plotly_fig, filename=htmlfile, **kwargs)
             self.htmlfiles.append(htmlfile)
             plt.close(fig)
 
