@@ -2,8 +2,8 @@
 """
 This is the unittest for the General Functions module.
 
-python -m unittest -v test_general_functions.py
-python -m pytest --cov-report term-missing -v tests/test_general_functions.py
+python -m unittest -v tests/test_general_functions.py
+python -m pytest --cov=pyjams --cov-report term-missing -v tests/test_general_functions.py
 
 """
 from __future__ import division, absolute_import, print_function
